==> jackcess-2.0.1-sources.jar: com/healthmarketscience/jackcess/impl/query/MakeTableQueryImpl.java <==
/*
Copyright (c) 2008 Health Market Science, Inc.

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

You can contact Health Market Science at info@healthmarketscience.com
or at the following address:

Health Market Science
2700 Horizon Drive
Suite 200
King of Prussia, PA 19406
*/

package com.healthmarketscience.jackcess.impl.query;

import java.util.List;
import com.healthmarketscience.jackcess.query.MakeTableQuery;


/**
 * Concrete Query subclass which represents an table creation query, e.g.:
 * {@code SELECT <query> INTO <newTable>}
 * 
 * @author James Ahlborn
 */
public class MakeTableQueryImpl extends BaseSelectQueryImpl 
  implements MakeTableQuery
{

  public MakeTableQueryImpl(String name, List<Row> rows, int objectId, 
                            int objectFlag) {
    super(name, rows, objectId, objectFlag, Type.MAKE_TABLE);
  }

  public String getTargetTable() {
    return getTypeRow().name1;
  }

  public String getRemoteDbPath() {
    return getTypeRow().name2;
  }

  public String getRemoteDbType() {
    return getTypeRow().expression;
  }

  @Override
  protected void toSelectInto(StringBuilder builder) 
  {
    builder.append(" INTO ").append(getTargetTable());
    toRemoteDb(builder, getRemoteDbPath(), getRemoteDbType());
  }

  @Override
  protected void toSQLString(StringBuilder builder)
  {
    toSQLSelectString(builder, true);
  }  

}

==> jackcess-4.0.8-sources.jar: com/healthmarketscience/jackcess/impl/query/MakeTableQueryImpl.java <==
/*
Copyright (c) 2008 Health Market Science, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package com.healthmarketscience.jackcess.impl.query;

import java.util.List;
import com.healthmarketscience.jackcess.query.MakeTableQuery;


/**
 * Concrete Query subclass which represents an table creation query, e.g.:
 * {@code SELECT <query> INTO <newTable>}
 * 
 * @author James Ahlborn
 */
public class MakeTableQueryImpl extends BaseSelectQueryImpl 
  implements MakeTableQuery
{

  public MakeTableQueryImpl(String name, List<Row> rows, int objectId, 
                            int objectFlag) {
    super(name, rows, objectId, objectFlag, Type.MAKE_TABLE);
  }

  @Override
  public String getTargetTable() {
    return getTypeRow().name1;
  }

  @Override
  public String getRemoteDbPath() {
    return getTypeRow().name2;
  }

  @Override
  public String getRemoteDbType() {
    return getTypeRow().expression;
  }

  @Override
  protected void toSelectInto(StringBuilder builder) 
  {
    builder.append(" INTO ");
    toOptionalQuotedExpr(builder, getTargetTable(), true);
    toRemoteDb(builder, getRemoteDbPath(), getRemoteDbType());
  }

  @Override
  protected void toSQLString(StringBuilder builder)
  {
    toSQLSelectString(builder, true);
  }  

}
